aboutsummaryrefslogtreecommitdiffstats
path: root/os/hal/platforms/LPC111x/hal_lld.c
diff options
context:
space:
mode:
Diffstat (limited to 'os/hal/platforms/LPC111x/hal_lld.c')
-rw-r--r--os/hal/platforms/LPC111x/hal_lld.c13
1 files changed, 10 insertions, 3 deletions
diff --git a/os/hal/platforms/LPC111x/hal_lld.c b/os/hal/platforms/LPC111x/hal_lld.c
index 8674d4f38..919d1b0c7 100644
--- a/os/hal/platforms/LPC111x/hal_lld.c
+++ b/os/hal/platforms/LPC111x/hal_lld.c
@@ -18,10 +18,10 @@
*/
/**
* @file templates/hal_lld.c
* @brief HAL Driver subsystem low level driver source template.
*
- * @addtogroup HAL_LLD
+ * @addtogroup LPC111x_HAL
* @{
*/
@@ -55,4 +55,11 @@ void hal_lld_init(void) {
}
+/**
+ * @brief LPC111x clocks and PLL initialization.
+ * @note All the involved constants come from the file @p board.h.
+ */
+void lpc111x_clock_init(void) {
+}
+
/** @} */
@@ -18,10 +18,10 @@
*/
/**
- * @file templates/hal_lld.c
- * @brief HAL Driver subsystem low level driver source template.
+ * @file LPC111x/hal_lld.c
+ * @brief LPC111x HAL subsystem low level driver source.
*